#
# spec file for package kcalendarcore
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.76
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kcalendarcore
Version:        5.76.0
Release:        bp153.1.14
Summary:        Library to access and handle calendar data
License:        LGPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  cmake(LibIcal) >= 2.0
BuildRequires:  cmake(Qt5Core) >= 5.12.0
BuildRequires:  cmake(Qt5Gui) >= 5.12.0
BuildRequires:  cmake(Qt5Test) >= 5.12.0

%description
KCalendarCore is a library to provide access to and handling of calendar data.
It supports the standard formats iCalendar and vCalendar and the group
scheduling standard iTIP.

%package -n libKF5CalendarCore5
Summary:        Library to access to and handle calendar data
Group:          Development/Libraries/KDE

%description  -n libKF5CalendarCore5
KCalendarCore is a library to provide access to and handling of calendar data.
It supports the standard formats iCalendar and vCalendar and the group
scheduling standard iTIP.

%package devel
Summary:        Development files for kcalendarcore, a library to handle calendar data
Group:          Development/Libraries/KDE
Requires:       libKF5CalendarCore5 = %{version}
Requires:       cmake(LibIcal) >= 2.0
# kcalcore-devel version was 19.11.70 in the unstable repo, 19.08.1 in stable
Provides:       kcalcore-devel
Obsoletes:      kcalcore-devel < 19.12
# kcalcore5 was provided/obsoleted by kcalcore
Provides:       kcalcore5-devel
Obsoletes:      kcalcore5-devel < 19.12

%description devel
KCalendarCore is a library to provide access to and handling of calendar data.
It supports the standard formats iCalendar and vCalendar and the group
scheduling standard iTIP. This package contains the headers necessary to
develop applications making use of KCalendarCore.

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build

%post -n libKF5CalendarCore5 -p /sbin/ldconfig
%postun -n libKF5CalendarCore5 -p /sbin/ldconfig

%files -n libKF5CalendarCore5
%license LICENSES/*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5CalendarCore.so.*

%files devel
%license LICENSES/*
%{_kf5_cmakedir}/KF5CalendarCore/
%{_kf5_includedir}/KCalendarCore/
%{_kf5_includedir}/kcalcore_version.h
%{_kf5_includedir}/kcalendarcore_version.h
%{_kf5_libdir}/libKF5CalendarCore.so
%{_kf5_mkspecsdir}/qt_KCalendarCore.pri

%changelog
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Raise ambiguity in ICalFormat::toString() in tests
  * Make MemoryCalendar::rawEvents(QDate, QDate) works for open bounds
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Remove obsolete license text
  * Relicense file to LGPL-2.0-or-later
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Always store X-KDE-VOLATILE-XXX properties as volatile.
  * Document the expected TZ transitions in Prague
  * Remove obsolete COPYING files
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Fix unittests on FreeBSD.
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Correct documentation for Recurrence::setStartDateTime()
  * Check for write error in save() if the disk is full (kde#370708)
  * Correct icon names for recurring to-dos
  * Fix serialization of recurring to-do's start date (kde#345498)
  * Add more tests for Recurrence::getNextDayTime(QDateTime)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * fix fallback to vCalendar loading on iCalendar load failure
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Fix mismatching iterator types
  * Update visibility cache when notebook visibility is changed
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * KCalendarCore: Convert license statements to SPDX markers
  * Use ecm_qt_install_logging_categories over manual categories files
  * Port QRegExp to QRegularExpression
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Remove endl. qCritical/qDebug already adds a endl.
  * Improve README.md to have an Introduction section
  * Make incidence geographic coordinate also accessible as a property
  * Fix RRULE generation for timezones
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * autotests: Find perl executable on all platforms
  * Add some test to ensure local time handling in recurrences.
  * Fallback to system time zone on calendar creation with an invalid one.
  * Memory Calendar: avoid code duplication
  * Use QDate as key in mIncidencesForDate in MemoryCalendar
  * Handle incidences in different time zones in MemoryCalendar.
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Add libical version too
  * Fix typo
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Explicitly define the Journal copy ctor
* Tue Oct 15 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the license tag. kcalendarcore is LGPL-2.0-or-later.
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * kcalcore was renamed to kcalendarcore and is now a KDE framework.
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * "kcalcore_debug.h" -> "kcalendarcore_debug.h"
  * Rename to kcalendarcore
  * Rename kcalcore_version.h to kcalendarcore_version.h
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Clarify that utils.h is not public API
  * Port tests to new namespace
  * Rename the header install locations to KCalendarCore
  * Rename the KCalCore namespace to KCalendarCore
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Remove bogus TODO, this is a private header already so it's fine
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Fix compile, KCalCore doesn't depend on Qt5Widgets, so use Qt5Gui instead
  * Workaround a Qt 5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * compile without foreach
  * We use find_dependency, so we need to include CMakeFindDependencyMacro.
  * Support static builds
  * Add property for productId
  * Fix some clazy warning
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Fix TodoTest::testStatus
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * QT_NO_NARROWING_CONVERSIONS_IN_CONNECT is defined in kf5.51
  * Need to increase version
  * Make Incidence[Base] and Event Q_GADGETs
  * Use new syntax
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Use Q_REQUIRED_RESULT
  * Warning--
  * Warning--
  * Remove unused debug
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Fix Bug 392952 - Regression: port to QTimeZone leads to blowing up iCal file size (kde#392952)
* Tue Apr 10 2018 wbauer@tmo.at
- Add 0001-Revert-GIT_SILENT-increase-version.patch to make it
  build with libical 1.0.1 on Leap 42.3
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Remove unused unistd.h include
  * define strncasecmp and strcasecmp on Windows
  * Remove strings.h include
  * icalformat: remove QByteArray->QString->QByteArray roundtrip.
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix a porting bug when persing timezones
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Make sure the autotest fails if the .ref file is missing.
  * Fix obvious porting error, allDay was ignored.
  * Finish cleaning up after 4a039ac88, removing unused test files
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Remove duplicate QT_REQUIRED_VERSION from autotests
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Remove duplicate QT_REQUIRED_VERSION from autotests
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Fix build on Windows
  * Remove not necessary include
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Minor optimization
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Revert "USe nullptr"
  * USe nullptr
  * Port away from qt_qhash_seed which is going away in Qt 5.9
  * Minor
  * Minor optimization
  * Remove directly
  * USe directly value()...
  * Use nullptr
  * Use QLatin1Char
  * Use QLatin1Char when possible
  * Use Q_NULLPTR
  * Use QLatin1Char(' ') when possible
  * Add ECMCoverageOption
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Sat Jul 16 2016 wbauer@tmo.at
- Cleanup build requirements
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Fri Dec 11 2015 p.drouand@gmail.com
- Remove superfluous libpth-devel dependency
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial version based on  KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
